% Basic RBC Model
% + Adjustment costs on investment
% gauthier[at]vermandel.fr

close all;
%format long

%----------------------------------------------------------------
% 1. Defining variables
%----------------------------------------------------------------

var y
	c
	r
	w
	h
	z
	q
	i
	k
	a g s_i
	lambdaC 
	;

varexo	e_a e_g e_i;

parameters	beta alpha delta sigmaC sigmaL gy
			chi_I
			rho_a rho_g rho_i
			% ss
			Z R Y C I Q
			;

%----------------------------------------------------------------
% 2. Calibration
%----------------------------------------------------------------
% Loading calibration
@#include "calibration.mod"


%----------------------------------------------------------------
% 3. Model
%----------------------------------------------------------------
model(linear);
    %% Household
	% Euler
	c(+1) - c = (1/sigmaC)*r;
	% Labor Supply
	w=(1/sigmaL)*h+sigmaC*c;
	% stochastic discount factor
	lambdaC=-sigmaC*c;
	
	%% Capital supply
	% No arbitrage Bonds-Capital
	r = (Z/R)*z(+1) + ((1-delta)/R)*q(+1) - q ;
	% Capital Law of motion
	delta*i = k - (1-delta)*k(-1);
	% Investment equation
	(1+beta)*i =  1/chi_I*q - s_i + i(-1) + beta*( s_i(+1) + i(+1) );
	
	% Firms
	% Production
	y = a + alpha*k(-1) +  (1-alpha)*h;
	% Inputs Cost minimization
	z = y - k(-1);
	w + h = z + k(-1);
	% Ressources Constraint
	Y*y = C*c + I*i + gy*Y*g ;
	
    % Exogenous shocks
	a = rho_a*a(-1) + e_a;
	g = rho_g*g(-1) + e_g;
	s_i = rho_i*s_i(-1)+e_i;
end;

%----------------------------------------------------------------
% 4. Computation
%----------------------------------------------------------------
check;
%steady;

shocks;
var e_a;  stderr .01;
var e_g;  stderr .01;
var e_i;  stderr .01;
end;

stoch_simul(order=1,irf=30) y c i r q k ;